/*
 * Copyright (C) 2016 Canonical, Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of version 3 of the GNU Lesser General Public License as published
 * by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Gary Wang  <gary.wang@canonical.com>
 */

#ifndef MCLOUD_API_CLOUDFOLDER_H_
#define MCLOUD_API_CLOUDFOLDER_H_

#include <mcloud/api/cloudresource.h>
#include <mcloud/api/visibility.h>

#include <memory>
#include <string>
#include <ctime>

namespace tinyxml2 {
    class XMLElement;
}

namespace mcloud {
namespace api {

/*!
    \class CloudFolder
    \brief CloudFolder represents a folder object in mcloud.
 */

class MCLOUD_API_DLL_PUBLIC CloudFolder : public CloudResource {
public:
    enum class FolderType {
        normal = 0,
        pictures,
        music,
        videos,
        message,
        docs,
        app,
        sync,
    };

    typedef std::shared_ptr<CloudFolder> Ptr;

    virtual ~CloudFolder() = default;

    /*!
     * \brief Returns a unique id of cloud folder object.
     */
    const std::string &id() const override;

    /*!
     * \brief Returns the name of cloud folder object.
     */
    const std::string &name() const override;

    /*!
     * \brief Returns the datetime when folder was created.
     */
    const std::time_t &create_date() const override;

    /*!
     * \brief Returns the datetime when folder was updated.
     */
    const std::time_t &update_date() const override;

    /*!
     * \brief Returns a unique id of the parent folder.
     */
    const std::string &parent_catalog_id() const override;

    /*!
     * \brief Returns owner id of a folder object.
     */
    const std::string &owner() const override;

    /*!
     * \brief Returns resource property of an object.
     */
    CloudResource::Property property() const override;

    /*!
     * \brief Returns type of this folder object.
     * \sa FolderType
     */
    FolderType folder_type() const;

private:
    CloudFolder(const tinyxml2::XMLElement *root);

    friend class ClientPriv;

    class Priv;
    std::shared_ptr<Priv>   p;
};

}
}

#endif // MCLOUD_API_CLOUDFOLDER_H_
