/*
 * Copyright (C) 2016 Canonical, Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of version 3 of the GNU Lesser General Public License as published
 * by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Gary Wang <gary.wang@canonical.com>
 */

#ifndef MCLOUD_API_CLOUDRESOURCE_H_
#define MCLOUD_API_CLOUDRESOURCE_H_

#include <memory>
#include <string>
#include <ctime>

namespace mcloud {
namespace api {

/*!
    \class CloudResource
    \brief CloudResource is an abstract object inherited by CloudFolder CloudContent private object.
    It provides the abstract interface for cloud folder and content classes.
 */

class CloudResource {
  public:
    enum class Property {
        content,  ///< content resource
        folder    ///< folder resource
    };

    CloudResource() = default;

    virtual ~CloudResource() = default;

    virtual const std::string &id() const = 0;

    virtual const std::string &name() const = 0;

    virtual const std::time_t &create_date() const = 0;

    virtual const std::time_t &update_date() const = 0;

    virtual const std::string &parent_catalog_id() const = 0;

    virtual const std::string &owner() const = 0;

    virtual Property property() const = 0;
};

}
}

#endif // MCLOUD_API_CLOUDRESOURCE_H_
