/*
 * Copyright (C) 2014 Canonical, Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of version 3 of the GNU Lesser General Public License as published
 * by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:  Gary Wang  <gary.wang@canonical.com>
 */

#include <boost/filesystem.hpp>
#include <boost/algorithm/string.hpp>
#include <core/net/error.h>
#include <core/net/uri.h>
#include <core/net/http/client.h>
#include <core/net/http/request.h>
#include <core/net/http/response.h>
#include <tinyxml2.h>

#include <mcloud/api/client.h>

using namespace mcloud::api;
using namespace std;

#include "client_priv.h"

Client::Client(int request_timeout)
    : p(make_shared<ClientPriv>(request_timeout)) {
}

Client::~Client() {
    cancel_sync();
}

string Client::cloud_sync_folder_id() {
    return p->cloud_sync_folder_id();
}

bool Client::exist_on_cloud(const string &file_path) {
    return p->exist_on_cloud(file_path);
}

Client::DiskInfoPtr Client::disk_info() {
    return p->disk_info();
}

Client::ResourceList Client::cloud_content_list(int start_index,
                                                int count,
                                                Client::ContentType type,
                                                const std::string & folder_id) {
    return p->cloud_content_list(start_index, count, type, folder_id);
}

bool Client::delete_folders(const Stringlist &folder_ids) {
    return p->delete_folders(folder_ids);
}

bool Client::delete_contents(const vector<string> &content_ids) {
    return p->delete_contents(content_ids);
}

Client::OutlinkList Client::create_folder_extranet_link(const Stringlist &folder_ids) {
    return p->create_folder_extranet_link(folder_ids);
}

Client::OutlinkList Client::create_content_extranet_link(const Stringlist &content_ids) {
    return p->create_content_extranet_link(content_ids);
}

bool Client::refresh_token(const string &refresh_token) {
    return p->refersh_token(refresh_token);
}

void Client::cancel_sync() {
    p->cancel_sync();
}

void Client::start_sync() {
    p->start_sync();
}

void Client::pause_sync() {
    p->pause_sync();
}

Client::DownloadList Client::add_download_tasks(const Stringlist &contentId_list) {
    return p->add_download_tasks(contentId_list);
}

Client::UploadList Client::add_upload_tasks(const Stringlist &file_list) {
    return p->add_upload_tasks(file_list);
}

TaskQueue<Client::DownloadTaskPtr> Client::download_queue() {
    return p->download_queue();
}

TaskQueue<Client::UploadTaskPtr> Client::upload_queue() {
    return p->upload_queue();
}
