/*
 * Copyright (C) 2014 Canonical, Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of version 3 of the GNU Lesser General Public License as published
 * by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author:  Gary Wang  <gary.wang@canonical.com>
 */

#ifndef MCLOUD_API_CLIENTPRIV_H_
#define MCLOUD_API_CLIENTPRIV_H_

#include <mcloud/api/client.h>
#include <mcloud/api/visibility.h>
#include <mcloud/api/cloudresource.h>
#include <mcloud/api/taskqueue.h>

#include <deque>
#include <future>
#include <string>
#include <thread>
#include <vector>

namespace mcloud {
namespace api {

class SyncManager;
class DownloadTask;
class UploadTask;
class DiskInfo;
class Outlink;

class MCLOUD_API_DLL_LOCAL ClientPriv {
  public:

    ClientPriv(int request_timeout = 10);

    virtual ~ClientPriv();

    void set_auth_info(const std::string &access_token);

    bool refersh_token(const std::string &refresh_token);

    std::shared_ptr<DiskInfo> disk_info();

    std::string cloud_sync_folder_id();

    bool exist_on_cloud(const std::string &file_path);

    Client::ResourceList cloud_content_list(int start_index,
                                    int count,
                                    Client::ContentType content_type = Client::ContentType::all,
                                    const std::string &folder_id = std::string());

    bool delete_folders(const Client::Stringlist &folder_ids);

    bool delete_contents(const Client::Stringlist &content_ids);

    Client::OutlinkList create_folder_extranet_link(const Client::Stringlist &folder_ids);

    Client::OutlinkList create_content_extranet_link(const Client::Stringlist &content_ids);

    void cancel_sync();

    void start_sync();

    void pause_sync();

    Client::DownloadList add_download_tasks(const Client::Stringlist  &contentId_list);

    Client::UploadList add_upload_tasks(const Client::Stringlist  &file_list);

    Client::DownloadList download_queue();

    Client::UploadList upload_queue();

    void cancel();
  private:
    Client::ResourceList cloud_root_folder_list();

    bool delete_internal(const std::string &postbody);

    Client::OutlinkList create_extranet_internal(const std::string &postbody);

    Client::DownloadList create_download_link(const Client::Stringlist  &content_ids);

    //Same name files in different directories are not allowed according to mcloud api
    Client::UploadList create_upload_link(const Client::Stringlist  &file_paths,
                                       const std::string &cloud_folder_id = std::string());

    template<typename T> T get_or_throw(std::future<T> &f);

    void add_download_task(Client::DownloadTaskPtr task);

    void add_upload_task(Client::UploadTaskPtr task);

  private:
    class HttpClient;

    std::shared_ptr<HttpClient>  client_;

    std::shared_ptr<SyncManager> sync_manager_;
};

}
}

#endif // MCLOUD_API_CLIENTPRIV_H_
