/*
 * Copyright © 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Gary Wang <gary.wang@canonical.com>
 */

#include <boost/algorithm/string.hpp>
#include <mcloud/api/cloudcontent.h>

#include <tinyxml2.h>

using namespace mcloud::api;
using namespace std;

extern std::time_t string_to_time(const std::string dt);

class CloudContent::Priv {
public:
    Priv(const tinyxml2::XMLElement *root) {
        name_= root->FirstChildElement("contentName")->GetText();
        id_ = root->FirstChildElement("contentID")->GetText();
        create_date_ = string_to_time(root->FirstChildElement("uploadTime")->GetText());
        update_date_ = string_to_time(root->FirstChildElement("updateTime")->GetText());
        parent_catalog_id_ = root->FirstChildElement("parentCatalogId")->GetText();
        owner_ = root->FirstChildElement("owner")->GetText();
        suffix_ = root->FirstChildElement("contentSuffix")->GetText();
        content_size_ = atoi(root->FirstChildElement("contentSize")->GetText());
        content_type_ = (Client::ContentType)atoi(root->FirstChildElement("contentType")->GetText());

        auto desc_ele = root->FirstChildElement("contentDesc");
        if (desc_ele && desc_ele->GetText()) {
            description_ = desc_ele->GetText();
        }

        auto thumbnail_ele = root->FirstChildElement("thumbnailURL");
        if (thumbnail_ele && thumbnail_ele->GetText()) {
            thumbnail_url_ = thumbnail_ele->GetText();
        }

        auto big_thumbnail_ele = root->FirstChildElement("bigthumbnailURL");
        if (big_thumbnail_ele && big_thumbnail_ele->GetText()) {
            big_thumbnail_url_ = big_thumbnail_ele->GetText();
        }

        auto present_ele = root->FirstChildElement("presentURL");
        if (present_ele && present_ele->GetText()) {
            present_url_ = present_ele->GetText();
        }

    #ifndef NDEBUG
        cout << name_ << endl;
        cout << id_ << endl;
    #endif
    }

public:
  std::string id_;

  std::string name_;

  std::time_t create_date_;

  std::time_t update_date_;

  std::string owner_;

  std::string suffix_;

  Client::ContentType content_type_;

  int64_t     content_size_;

  std::string description_;

  std::string thumbnail_url_;

  std::string big_thumbnail_url_;

  std::string present_url_;

  std::string parent_catalog_id_;
};

CloudContent::CloudContent(const tinyxml2::XMLElement *root)
    : p(std::make_shared<Priv>(root)){
}

const string &CloudContent::id() const {
    return p->id_;
}

const string &CloudContent::name() const {
    return  p->name_;
}

const time_t &CloudContent::create_date() const {
    return p->create_date_;
}

const time_t &CloudContent::update_date() const {
    return p->update_date_;
}

const string &CloudContent::parent_catalog_id() const {
    return p->parent_catalog_id_;
}

const string &CloudContent::owner() const {
    return p->owner_;
}

CloudResource::Property CloudContent::property() const {
    return CloudResource::Property::content;
}

const string &CloudContent::suffix() const {
    return p->suffix_;
}

Client::ContentType CloudContent::content_type() const {
    return p->content_type_;
}

int64_t CloudContent::content_size() const {
    return p->content_size_;
}

const string &CloudContent::description() const {
    return p->description_;
}

const string &CloudContent::thumbnail_url() const {
    return p->thumbnail_url_;
}

const string &CloudContent::big_thumbnail_url() const {
    return p->big_thumbnail_url_;
}

const string &CloudContent::present_url() const {
    return p->present_url_;
}
