/*
 * Copyright © 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Gary Wang <gary.wang@canonical.com>
 */

#include <boost/algorithm/string.hpp>

#include <mcloud/api/cloudfolder.h>

#include <tinyxml2.h>
#include <sstream>
#include <time.h>

using namespace mcloud::api;
using namespace std;

std::time_t string_to_time(const std::string dt) {
    struct std::tm tm;
    std::istringstream ss(dt);
    strptime(dt.c_str(), "%Y%m%d%H%M%S",&tm); // std::get std::put only available in GCC 5
    return std::mktime(&tm);
}

class CloudFolder::Priv {
public:
    Priv(const tinyxml2::XMLElement *root) {
        name_= root->FirstChildElement("catalogName")->GetText();
        id_ = root->FirstChildElement("catalogID")->GetText();
        create_date_ = string_to_time(root->FirstChildElement("createTime")->GetText());
        update_date_ = string_to_time(root->FirstChildElement("updateTime")->GetText());
        parent_catalog_id_ = root->FirstChildElement("parentCatalogId")->GetText();
        owner_ = root->FirstChildElement("owner")->GetText();
        folder_type_ = (FolderType)atoi(root->FirstChildElement("catalogType")->GetText());

    #ifndef NDEBUG
        cout << name_ << endl;
        cout << id_ << endl;
    #endif
    }

    std::string id_;

    std::string name_;

    std::time_t create_date_;

    std::time_t update_date_;

    std::string parent_catalog_id_;

    std::string owner_;

    CloudFolder::FolderType folder_type_;
};

CloudFolder::CloudFolder(const tinyxml2::XMLElement *root)
    :p(std::make_shared<Priv>(root)){
}

const string &CloudFolder::id() const {
    return p->id_;
}

const string &CloudFolder::name() const {
    return p->name_;
}

const time_t &CloudFolder::create_date() const {
    return p->create_date_;
}

const time_t &CloudFolder::update_date() const {
    return p->update_date_;
}

const string &CloudFolder::parent_catalog_id() const {
    return p->parent_catalog_id_;
}

const string &CloudFolder::owner() const {
    return p->owner_;
}

CloudResource::Property CloudFolder::property() const {
    return CloudResource::Property::folder;
}

CloudFolder::FolderType CloudFolder::folder_type() const {
    return p->folder_type_;
}

