/*
 * Copyright © 2016 Canonical Ltd.
 *
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License version 3,
 * as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Authored by: Gary Wang <gary.wang@canonical.com>
 */

#include "syncmanager.h"

using namespace mcloud::api;
using namespace std;

SyncManager::SyncManager():
    download_thread(),
    upload_thread() {
}

SyncManager::~SyncManager() {
    download_thread.stop();
    upload_thread.stop();
}

void SyncManager::push_download_task(std::shared_ptr<DownloadTask> task) {
    download_thread.push_task(task);
}

void SyncManager::push_upload_task(std::shared_ptr<UploadTask> task) {
    upload_thread.push_task(task);
}

TaskQueue<std::shared_ptr<DownloadTask>> SyncManager::download_queue() {
    return download_thread.task_queue();
}

TaskQueue<std::shared_ptr<UploadTask>> SyncManager::upload_queue() {
    return upload_thread.task_queue();
}

void SyncManager::start() {
    download_thread.start();
    upload_thread.start();
}

void SyncManager::cancel() {
    download_thread.cancel();
    upload_thread.cancel();
}

void SyncManager::pause() {
    download_thread.pause();
    upload_thread.pause();
}
