/*
 * Copyright (C) 2016 Canonical, Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of version 3 of the GNU Lesser General Public License as published
 * by the Free Software Foundation.
 *
 * This library is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
 * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
 * details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 *
 * Author: Gary Wang  <gary.wang@canonical.com>
 */

#ifndef MCLOUD_API_SYNCMANAGER_H_
#define MCLOUD_API_SYNCMANAGER_H_

#include <mcloud/api/downloadtask.h>
#include <mcloud/api/uploadtask.h>
#include <mcloud/api/visibility.h>

#include "syncthread.h"

namespace mcloud {
namespace api {

class MCLOUD_API_DLL_LOCAL SyncManager {
  public:
    typedef std::shared_ptr<SyncManager> Ptr;

    SyncManager();

    virtual ~SyncManager();

    void push_download_task(std::shared_ptr<DownloadTask> task);

    void push_upload_task(std::shared_ptr<UploadTask> task);

    TaskQueue<std::shared_ptr<DownloadTask>>  download_queue();

    TaskQueue<std::shared_ptr<UploadTask>>    upload_queue();

    void start();

    void cancel();

    void pause();
private:
    SyncThread<DownloadTask>   download_thread;
    SyncThread<UploadTask>     upload_thread;
};

}
}

#endif // MCLOUD_API_SYNCMANAGER_H_
